# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/formatter/req_without_query/v3/req_without_query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGenvoy/extensions/formatter/req_without_query/v3/req_without_query.proto\x12/envoy.extensions.formatter.req_without_query.v3\x1a\x1dudpa/annotations/status.proto\"\x11\n\x0fReqWithoutQueryB\xcb\x01\n=io.envoyproxy.envoy.extensions.formatter.req_without_query.v3B\x14ReqWithoutQueryProtoP\x01Zjgithub.com/envoyproxy/go-control-plane/envoy/extensions/formatter/req_without_query/v3;req_without_queryv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.formatter.req_without_query.v3.req_without_query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n=io.envoyproxy.envoy.extensions.formatter.req_without_query.v3B\024ReqWithoutQueryProtoP\001Zjgithub.com/envoyproxy/go-control-plane/envoy/extensions/formatter/req_without_query/v3;req_without_queryv3\272\200\310\321\006\002\020\002'
  _globals['_REQWITHOUTQUERY']._serialized_start=155
  _globals['_REQWITHOUTQUERY']._serialized_end=172
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/status/v3/csds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.admin.v3 import config_dump_shared_pb2 as envoy_dot_admin_dot_v3_dot_config__dump__shared__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.type.matcher.v3 import node_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_node__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"envoy/service/status/v3/csds.proto\x12\x17\x65nvoy.service.status.v3\x1a\'envoy/admin/v3/config_dump_shared.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a envoy/type/matcher/v3/node.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xae\x01\n\x13\x43lientStatusRequest\x12\x39\n\rnode_matchers\x18\x01 \x03(\x0b\x32\".envoy.type.matcher.v3.NodeMatcher\x12(\n\x04node\x18\x02 \x01(\x0b\x32\x1a.envoy.config.core.v3.Node:2\x9a\xc5\x88\x1e-\n+envoy.service.status.v2.ClientStatusRequest\"\x94\x04\n\x0cPerXdsConfig\x12\x35\n\x06status\x18\x01 \x01(\x0e\x32%.envoy.service.status.v3.ConfigStatus\x12O\n\rclient_status\x18\x07 \x01(\x0e\x32+.envoy.service.status.v3.ClientConfigStatusB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12>\n\x0flistener_config\x18\x02 \x01(\x0b\x32#.envoy.admin.v3.ListenersConfigDumpH\x00\x12<\n\x0e\x63luster_config\x18\x03 \x01(\x0b\x32\".envoy.admin.v3.ClustersConfigDumpH\x00\x12\x38\n\x0croute_config\x18\x04 \x01(\x0b\x32 .envoy.admin.v3.RoutesConfigDumpH\x00\x12\x45\n\x13scoped_route_config\x18\x05 \x01(\x0b\x32&.envoy.admin.v3.ScopedRoutesConfigDumpH\x00\x12>\n\x0f\x65ndpoint_config\x18\x06 \x01(\x0b\x32#.envoy.admin.v3.EndpointsConfigDumpH\x00:+\x9a\xc5\x88\x1e&\n$envoy.service.status.v2.PerXdsConfigB\x10\n\x0eper_xds_config\"\xf9\x04\n\x0c\x43lientConfig\x12(\n\x04node\x18\x01 \x01(\x0b\x32\x1a.envoy.config.core.v3.Node\x12\x46\n\nxds_config\x18\x02 \x03(\x0b\x32%.envoy.service.status.v3.PerXdsConfigB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12S\n\x13generic_xds_configs\x18\x03 \x03(\x0b\x32\x36.envoy.service.status.v3.ClientConfig.GenericXdsConfig\x1a\xf4\x02\n\x10GenericXdsConfig\x12\x10\n\x08type_url\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0cversion_info\x18\x03 \x01(\t\x12(\n\nxds_config\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x0clast_updated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\rconfig_status\x18\x06 \x01(\x0e\x32%.envoy.service.status.v3.ConfigStatus\x12;\n\rclient_status\x18\x07 \x01(\x0e\x32$.envoy.admin.v3.ClientResourceStatus\x12\x37\n\x0b\x65rror_state\x18\x08 \x01(\x0b\x32\".envoy.admin.v3.UpdateFailureState\x12\x1a\n\x12is_static_resource\x18\t \x01(\x08:+\x9a\xc5\x88\x1e&\n$envoy.service.status.v2.ClientConfig\"\x82\x01\n\x14\x43lientStatusResponse\x12\x35\n\x06\x63onfig\x18\x01 \x03(\x0b\x32%.envoy.service.status.v3.ClientConfig:3\x9a\xc5\x88\x1e.\n,envoy.service.status.v2.ClientStatusResponse*K\n\x0c\x43onfigStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06SYNCED\x10\x01\x12\x0c\n\x08NOT_SENT\x10\x02\x12\t\n\x05STALE\x10\x03\x12\t\n\x05\x45RROR\x10\x04*c\n\x12\x43lientConfigStatus\x12\x12\n\x0e\x43LIENT_UNKNOWN\x10\x00\x12\x14\n\x10\x43LIENT_REQUESTED\x10\x01\x12\x10\n\x0c\x43LIENT_ACKED\x10\x02\x12\x11\n\rCLIENT_NACKED\x10\x03\x32\xb2\x02\n\x1c\x43lientStatusDiscoveryService\x12w\n\x12StreamClientStatus\x12,.envoy.service.status.v3.ClientStatusRequest\x1a-.envoy.service.status.v3.ClientStatusResponse\"\x00(\x01\x30\x01\x12\x98\x01\n\x11\x46\x65tchClientStatus\x12,.envoy.service.status.v3.ClientStatusRequest\x1a-.envoy.service.status.v3.ClientStatusResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/v3/discovery:client_status:\x01*B\x85\x01\n%io.envoyproxy.envoy.service.status.v3B\tCsdsProtoP\x01ZGgithub.com/envoyproxy/go-control-plane/envoy/service/status/v3;statusv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.status.v3.csds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.envoyproxy.envoy.service.status.v3B\tCsdsProtoP\001ZGgithub.com/envoyproxy/go-control-plane/envoy/service/status/v3;statusv3\272\200\310\321\006\002\020\002'
  _CLIENTSTATUSREQUEST._options = None
  _CLIENTSTATUSREQUEST._serialized_options = b'\232\305\210\036-\n+envoy.service.status.v2.ClientStatusRequest'
  _PERXDSCONFIG.fields_by_name['client_status']._options = None
  _PERXDSCONFIG.fields_by_name['client_status']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _PERXDSCONFIG._options = None
  _PERXDSCONFIG._serialized_options = b'\232\305\210\036&\n$envoy.service.status.v2.PerXdsConfig'
  _CLIENTCONFIG.fields_by_name['xds_config']._options = None
  _CLIENTCONFIG.fields_by_name['xds_config']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _CLIENTCONFIG._options = None
  _CLIENTCONFIG._serialized_options = b'\232\305\210\036&\n$envoy.service.status.v2.ClientConfig'
  _CLIENTSTATUSRESPONSE._options = None
  _CLIENTSTATUSRESPONSE._serialized_options = b'\232\305\210\036.\n,envoy.service.status.v2.ClientStatusResponse'
  _CLIENTSTATUSDISCOVERYSERVICE.methods_by_name['FetchClientStatus']._options = None
  _CLIENTSTATUSDISCOVERYSERVICE.methods_by_name['FetchClientStatus']._serialized_options = b'\202\323\344\223\002 \"\033/v3/discovery:client_status:\001*'
  _globals['_CONFIGSTATUS']._serialized_start=1845
  _globals['_CONFIGSTATUS']._serialized_end=1920
  _globals['_CLIENTCONFIGSTATUS']._serialized_start=1922
  _globals['_CLIENTCONFIGSTATUS']._serialized_end=2021
  _globals['_CLIENTSTATUSREQUEST']._serialized_start=365
  _globals['_CLIENTSTATUSREQUEST']._serialized_end=539
  _globals['_PERXDSCONFIG']._serialized_start=542
  _globals['_PERXDSCONFIG']._serialized_end=1074
  _globals['_CLIENTCONFIG']._serialized_start=1077
  _globals['_CLIENTCONFIG']._serialized_end=1710
  _globals['_CLIENTCONFIG_GENERICXDSCONFIG']._serialized_start=1293
  _globals['_CLIENTCONFIG_GENERICXDSCONFIG']._serialized_end=1665
  _globals['_CLIENTSTATUSRESPONSE']._serialized_start=1713
  _globals['_CLIENTSTATUSRESPONSE']._serialized_end=1843
  _globals['_CLIENTSTATUSDISCOVERYSERVICE']._serialized_start=2024
  _globals['_CLIENTSTATUSDISCOVERYSERVICE']._serialized_end=2330
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.auth import tls_pb2 as envoy_dot_api_dot_v2_dot_auth_dot_tls__pb2
from envoy.api.v2.cluster import circuit_breaker_pb2 as envoy_dot_api_dot_v2_dot_cluster_dot_circuit__breaker__pb2
from envoy.api.v2.cluster import filter_pb2 as envoy_dot_api_dot_v2_dot_cluster_dot_filter__pb2
from envoy.api.v2.cluster import outlier_detection_pb2 as envoy_dot_api_dot_v2_dot_cluster_dot_outlier__detection__pb2
from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import config_source_pb2 as envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2
from envoy.api.v2.core import health_check_pb2 as envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2
from envoy.api.v2.core import protocol_pb2 as envoy_dot_api_dot_v2_dot_core_dot_protocol__pb2
from envoy.api.v2 import endpoint_pb2 as envoy_dot_api_dot_v2_dot_endpoint__pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65nvoy/api/v2/cluster.proto\x12\x0c\x65nvoy.api.v2\x1a\x1b\x65nvoy/api/v2/auth/tls.proto\x1a*envoy/api/v2/cluster/circuit_breaker.proto\x1a!envoy/api/v2/cluster/filter.proto\x1a,envoy/api/v2/cluster/outlier_detection.proto\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a%envoy/api/v2/core/config_source.proto\x1a$envoy/api/v2/core/health_check.proto\x1a envoy/api/v2/core/protocol.proto\x1a\x1b\x65nvoy/api/v2/endpoint.proto\x1a\x18\x65nvoy/type/percent.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xad.\n\x07\x43luster\x12L\n\x18transport_socket_matches\x18+ \x03(\x0b\x32*.envoy.api.v2.Cluster.TransportSocketMatch\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x15\n\ralt_stat_name\x18\x1c \x01(\t\x12=\n\x04type\x18\x02 \x01(\x0e\x32#.envoy.api.v2.Cluster.DiscoveryTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01H\x00\x12?\n\x0c\x63luster_type\x18& \x01(\x0b\x32\'.envoy.api.v2.Cluster.CustomClusterTypeH\x00\x12\x42\n\x12\x65\x64s_cluster_config\x18\x03 \x01(\x0b\x32&.envoy.api.v2.Cluster.EdsClusterConfig\x12<\n\x0f\x63onnect_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12G\n!per_connection_buffer_limit_bytes\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12;\n\tlb_policy\x18\x06 \x01(\x0e\x32\x1e.envoy.api.v2.Cluster.LbPolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12-\n\x05hosts\x18\x07 \x03(\x0b\x32\x1a.envoy.api.v2.core.AddressB\x02\x18\x01\x12<\n\x0fload_assignment\x18! \x01(\x0b\x32#.envoy.api.v2.ClusterLoadAssignment\x12\x35\n\rhealth_checks\x18\x08 \x03(\x0b\x32\x1e.envoy.api.v2.core.HealthCheck\x12\x41\n\x1bmax_requests_per_connection\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12?\n\x10\x63ircuit_breakers\x18\n \x01(\x0b\x32%.envoy.api.v2.cluster.CircuitBreakers\x12\x44\n\x0btls_context\x18\x0b \x01(\x0b\x32%.envoy.api.v2.auth.UpstreamTlsContextB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12V\n\x1eupstream_http_protocol_options\x18. \x01(\x0b\x32..envoy.api.v2.core.UpstreamHttpProtocolOptions\x12L\n\x1c\x63ommon_http_protocol_options\x18\x1d \x01(\x0b\x32&.envoy.api.v2.core.HttpProtocolOptions\x12\x46\n\x15http_protocol_options\x18\r \x01(\x0b\x32\'.envoy.api.v2.core.Http1ProtocolOptions\x12G\n\x16http2_protocol_options\x18\x0e \x01(\x0b\x32\'.envoy.api.v2.core.Http2ProtocolOptions\x12\x61\n\x1a\x65xtension_protocol_options\x18# \x03(\x0b\x32\x33.envoy.api.v2.Cluster.ExtensionProtocolOptionsEntryB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x62\n typed_extension_protocol_options\x18$ \x03(\x0b\x32\x38.envoy.api.v2.Cluster.TypedExtensionProtocolOptionsEntry\x12\x41\n\x10\x64ns_refresh_rate\x18\x10 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06*\x04\x10\xc0\x84=\x12\x43\n\x18\x64ns_failure_refresh_rate\x18, \x01(\x0b\x32!.envoy.api.v2.Cluster.RefreshRate\x12\x17\n\x0frespect_dns_ttl\x18\' \x01(\x08\x12J\n\x11\x64ns_lookup_family\x18\x11 \x01(\x0e\x32%.envoy.api.v2.Cluster.DnsLookupFamilyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x31\n\rdns_resolvers\x18\x12 \x03(\x0b\x32\x1a.envoy.api.v2.core.Address\x12\x1f\n\x17use_tcp_for_dns_lookups\x18- \x01(\x08\x12\x41\n\x11outlier_detection\x18\x13 \x01(\x0b\x32&.envoy.api.v2.cluster.OutlierDetection\x12=\n\x10\x63leanup_interval\x18\x14 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12;\n\x14upstream_bind_config\x18\x15 \x01(\x0b\x32\x1d.envoy.api.v2.core.BindConfig\x12>\n\x10lb_subset_config\x18\x16 \x01(\x0b\x32$.envoy.api.v2.Cluster.LbSubsetConfig\x12\x45\n\x13ring_hash_lb_config\x18\x17 \x01(\x0b\x32&.envoy.api.v2.Cluster.RingHashLbConfigH\x01\x12K\n\x16original_dst_lb_config\x18\" \x01(\x0b\x32).envoy.api.v2.Cluster.OriginalDstLbConfigH\x01\x12M\n\x17least_request_lb_config\x18% \x01(\x0b\x32*.envoy.api.v2.Cluster.LeastRequestLbConfigH\x01\x12>\n\x10\x63ommon_lb_config\x18\x1b \x01(\x0b\x32$.envoy.api.v2.Cluster.CommonLbConfig\x12<\n\x10transport_socket\x18\x18 \x01(\x0b\x32\".envoy.api.v2.core.TransportSocket\x12-\n\x08metadata\x18\x19 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12J\n\x12protocol_selection\x18\x1a \x01(\x0e\x32..envoy.api.v2.Cluster.ClusterProtocolSelection\x12L\n\x1bupstream_connection_options\x18\x1e \x01(\x0b\x32\'.envoy.api.v2.UpstreamConnectionOptions\x12\x30\n(close_connections_on_host_health_failure\x18\x1f \x01(\x08\x12P\n!drain_connections_on_host_removal\x18  \x01(\x08\x42%\xf2\x98\xfe\x8f\x05\x1f\n\x1dignore_health_on_host_removal\x12-\n\x07\x66ilters\x18( \x03(\x0b\x32\x1c.envoy.api.v2.cluster.Filter\x12@\n\x15load_balancing_policy\x18) \x01(\x0b\x32!.envoy.api.v2.LoadBalancingPolicy\x12\x33\n\nlrs_server\x18* \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSource\x12\x1d\n\x15track_timeout_budgets\x18/ \x01(\x08\x1a\x93\x01\n\x14TransportSocketMatch\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12&\n\x05match\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12<\n\x10transport_socket\x18\x03 \x01(\x0b\x32\".envoy.api.v2.core.TransportSocket\x1aV\n\x11\x43ustomClusterType\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12*\n\x0ctyped_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x1a]\n\x10\x45\x64sClusterConfig\x12\x33\n\neds_config\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSource\x12\x14\n\x0cservice_name\x18\x02 \x01(\t\x1a\xe3\x05\n\x0eLbSubsetConfig\x12^\n\x0f\x66\x61llback_policy\x18\x01 \x01(\x0e\x32;.envoy.api.v2.Cluster.LbSubsetConfig.LbSubsetFallbackPolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12/\n\x0e\x64\x65\x66\x61ult_subset\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12O\n\x10subset_selectors\x18\x03 \x03(\x0b\x32\x35.envoy.api.v2.Cluster.LbSubsetConfig.LbSubsetSelector\x12\x1d\n\x15locality_weight_aware\x18\x04 \x01(\x08\x12\x1d\n\x15scale_locality_weight\x18\x05 \x01(\x08\x12\x16\n\x0epanic_mode_any\x18\x06 \x01(\x08\x12\x13\n\x0blist_as_any\x18\x07 \x01(\x08\x1a\xb2\x02\n\x10LbSubsetSelector\x12\x0c\n\x04keys\x18\x01 \x03(\t\x12w\n\x0f\x66\x61llback_policy\x18\x02 \x01(\x0e\x32T.envoy.api.v2.Cluster.LbSubsetConfig.LbSubsetSelector.LbSubsetSelectorFallbackPolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x1c\n\x14\x66\x61llback_keys_subset\x18\x03 \x03(\t\"y\n\x1eLbSubsetSelectorFallbackPolicy\x12\x0f\n\x0bNOT_DEFINED\x10\x00\x12\x0f\n\x0bNO_FALLBACK\x10\x01\x12\x10\n\x0c\x41NY_ENDPOINT\x10\x02\x12\x12\n\x0e\x44\x45\x46\x41ULT_SUBSET\x10\x03\x12\x0f\n\x0bKEYS_SUBSET\x10\x04\"O\n\x16LbSubsetFallbackPolicy\x12\x0f\n\x0bNO_FALLBACK\x10\x00\x12\x10\n\x0c\x41NY_ENDPOINT\x10\x01\x12\x12\n\x0e\x44\x45\x46\x41ULT_SUBSET\x10\x02\x1aS\n\x14LeastRequestLbConfig\x12;\n\x0c\x63hoice_count\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x02\x1a\xa8\x02\n\x10RingHashLbConfig\x12\x43\n\x11minimum_ring_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\n\xfa\x42\x07\x32\x05\x18\x80\x80\x80\x04\x12T\n\rhash_function\x18\x03 \x01(\x0e\x32\x33.envoy.api.v2.Cluster.RingHashLbConfig.HashFunctionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x43\n\x11maximum_ring_size\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\n\xfa\x42\x07\x32\x05\x18\x80\x80\x80\x04\".\n\x0cHashFunction\x12\x0b\n\x07XX_HASH\x10\x00\x12\x11\n\rMURMUR_HASH_2\x10\x01J\x04\x08\x02\x10\x03\x1a.\n\x13OriginalDstLbConfig\x12\x17\n\x0fuse_http_header\x18\x01 \x01(\x08\x1a\x8c\x06\n\x0e\x43ommonLbConfig\x12\x34\n\x17healthy_panic_threshold\x18\x01 \x01(\x0b\x32\x13.envoy.type.Percent\x12V\n\x14zone_aware_lb_config\x18\x02 \x01(\x0b\x32\x36.envoy.api.v2.Cluster.CommonLbConfig.ZoneAwareLbConfigH\x00\x12\x64\n\x1blocality_weighted_lb_config\x18\x03 \x01(\x0b\x32=.envoy.api.v2.Cluster.CommonLbConfig.LocalityWeightedLbConfigH\x00\x12\x36\n\x13update_merge_window\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\'\n\x1fignore_new_hosts_until_first_hc\x18\x05 \x01(\x08\x12,\n$close_connections_on_host_set_change\x18\x06 \x01(\x08\x12\x64\n\x1c\x63onsistent_hashing_lb_config\x18\x07 \x01(\x0b\x32>.envoy.api.v2.Cluster.CommonLbConfig.ConsistentHashingLbConfig\x1a\x98\x01\n\x11ZoneAwareLbConfig\x12,\n\x0frouting_enabled\x18\x01 \x01(\x0b\x32\x13.envoy.type.Percent\x12\x36\n\x10min_cluster_size\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1d\n\x15\x66\x61il_traffic_on_panic\x18\x03 \x01(\x08\x1a\x1a\n\x18LocalityWeightedLbConfig\x1a=\n\x19\x43onsistentHashingLbConfig\x12 \n\x18use_hostname_for_hashing\x18\x01 \x01(\x08\x42\x1b\n\x19locality_config_specifier\x1a\x8e\x01\n\x0bRefreshRate\x12@\n\rbase_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xfa\x42\x0b\xaa\x01\x08\x08\x01*\x04\x10\xc0\x84=\x12=\n\x0cmax_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06*\x04\x10\xc0\x84=\x1aX\n\x1d\x45xtensionProtocolOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\x1aZ\n\"TypedExtensionProtocolOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\"W\n\rDiscoveryType\x12\n\n\x06STATIC\x10\x00\x12\x0e\n\nSTRICT_DNS\x10\x01\x12\x0f\n\x0bLOGICAL_DNS\x10\x02\x12\x07\n\x03\x45\x44S\x10\x03\x12\x10\n\x0cORIGINAL_DST\x10\x04\"\xac\x01\n\x08LbPolicy\x12\x0f\n\x0bROUND_ROBIN\x10\x00\x12\x11\n\rLEAST_REQUEST\x10\x01\x12\r\n\tRING_HASH\x10\x02\x12\n\n\x06RANDOM\x10\x03\x12\x1d\n\x0fORIGINAL_DST_LB\x10\x04\x1a\x08\x08\x01\xa8\xf7\xb4\x8b\x02\x01\x12\n\n\x06MAGLEV\x10\x05\x12\x14\n\x10\x43LUSTER_PROVIDED\x10\x06\x12 \n\x1cLOAD_BALANCING_POLICY_CONFIG\x10\x07\"5\n\x0f\x44nsLookupFamily\x12\x08\n\x04\x41UTO\x10\x00\x12\x0b\n\x07V4_ONLY\x10\x01\x12\x0b\n\x07V6_ONLY\x10\x02\"T\n\x18\x43lusterProtocolSelection\x12\x1b\n\x17USE_CONFIGURED_PROTOCOL\x10\x00\x12\x1b\n\x17USE_DOWNSTREAM_PROTOCOL\x10\x01\x42\x18\n\x16\x63luster_discovery_typeB\x0b\n\tlb_configJ\x04\x08\x0c\x10\rJ\x04\x08\x0f\x10\x10\"\xc2\x01\n\x13LoadBalancingPolicy\x12:\n\x08policies\x18\x01 \x03(\x0b\x32(.envoy.api.v2.LoadBalancingPolicy.Policy\x1ao\n\x06Policy\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01\x12*\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"H\n\x12UpstreamBindConfig\x12\x32\n\x0esource_address\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\"S\n\x19UpstreamConnectionOptions\x12\x36\n\rtcp_keepalive\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.core.TcpKeepaliveB\x8e\x01\n\x1aio.envoyproxy.envoy.api.v2B\x0c\x43lusterProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\xf2\x98\xfe\x8f\x05\x19\x12\x17\x65nvoy.config.cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032io.envoyproxy.envoy.api.v2B\014ClusterProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\362\230\376\217\005\031\022\027envoy.config.cluster.v3\272\200\310\321\006\002\020\001'
  _CLUSTER_TRANSPORTSOCKETMATCH.fields_by_name['name']._options = None
  _CLUSTER_TRANSPORTSOCKETMATCH.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CLUSTER_CUSTOMCLUSTERTYPE.fields_by_name['name']._options = None
  _CLUSTER_CUSTOMCLUSTERTYPE.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR.fields_by_name['fallback_policy']._options = None
  _CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR.fields_by_name['fallback_policy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CLUSTER_LBSUBSETCONFIG.fields_by_name['fallback_policy']._options = None
  _CLUSTER_LBSUBSETCONFIG.fields_by_name['fallback_policy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CLUSTER_LEASTREQUESTLBCONFIG.fields_by_name['choice_count']._options = None
  _CLUSTER_LEASTREQUESTLBCONFIG.fields_by_name['choice_count']._serialized_options = b'\372B\004*\002(\002'
  _CLUSTER_RINGHASHLBCONFIG.fields_by_name['minimum_ring_size']._options = None
  _CLUSTER_RINGHASHLBCONFIG.fields_by_name['minimum_ring_size']._serialized_options = b'\372B\0072\005\030\200\200\200\004'
  _CLUSTER_RINGHASHLBCONFIG.fields_by_name['hash_function']._options = None
  _CLUSTER_RINGHASHLBCONFIG.fields_by_name['hash_function']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CLUSTER_RINGHASHLBCONFIG.fields_by_name['maximum_ring_size']._options = None
  _CLUSTER_RINGHASHLBCONFIG.fields_by_name['maximum_ring_size']._serialized_options = b'\372B\0072\005\030\200\200\200\004'
  _CLUSTER_REFRESHRATE.fields_by_name['base_interval']._options = None
  _CLUSTER_REFRESHRATE.fields_by_name['base_interval']._serialized_options = b'\372B\013\252\001\010\010\001*\004\020\300\204='
  _CLUSTER_REFRESHRATE.fields_by_name['max_interval']._options = None
  _CLUSTER_REFRESHRATE.fields_by_name['max_interval']._serialized_options = b'\372B\t\252\001\006*\004\020\300\204='
  _CLUSTER_EXTENSIONPROTOCOLOPTIONSENTRY._options = None
  _CLUSTER_EXTENSIONPROTOCOLOPTIONSENTRY._serialized_options = b'8\001'
  _CLUSTER_TYPEDEXTENSIONPROTOCOLOPTIONSENTRY._options = None
  _CLUSTER_TYPEDEXTENSIONPROTOCOLOPTIONSENTRY._serialized_options = b'8\001'
  _CLUSTER_LBPOLICY.values_by_name["ORIGINAL_DST_LB"]._options = None
  _CLUSTER_LBPOLICY.values_by_name["ORIGINAL_DST_LB"]._serialized_options = b'\010\001\250\367\264\213\002\001'
  _CLUSTER.fields_by_name['name']._options = None
  _CLUSTER.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _CLUSTER.fields_by_name['type']._options = None
  _CLUSTER.fields_by_name['type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CLUSTER.fields_by_name['connect_timeout']._options = None
  _CLUSTER.fields_by_name['connect_timeout']._serialized_options = b'\372B\005\252\001\002*\000'
  _CLUSTER.fields_by_name['lb_policy']._options = None
  _CLUSTER.fields_by_name['lb_policy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CLUSTER.fields_by_name['hosts']._options = None
  _CLUSTER.fields_by_name['hosts']._serialized_options = b'\030\001'
  _CLUSTER.fields_by_name['tls_context']._options = None
  _CLUSTER.fields_by_name['tls_context']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _CLUSTER.fields_by_name['extension_protocol_options']._options = None
  _CLUSTER.fields_by_name['extension_protocol_options']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _CLUSTER.fields_by_name['dns_refresh_rate']._options = None
  _CLUSTER.fields_by_name['dns_refresh_rate']._serialized_options = b'\372B\t\252\001\006*\004\020\300\204='
  _CLUSTER.fields_by_name['dns_lookup_family']._options = None
  _CLUSTER.fields_by_name['dns_lookup_family']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CLUSTER.fields_by_name['cleanup_interval']._options = None
  _CLUSTER.fields_by_name['cleanup_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _CLUSTER.fields_by_name['drain_connections_on_host_removal']._options = None
  _CLUSTER.fields_by_name['drain_connections_on_host_removal']._serialized_options = b'\362\230\376\217\005\037\n\035ignore_health_on_host_removal'
  _LOADBALANCINGPOLICY_POLICY.fields_by_name['config']._options = None
  _LOADBALANCINGPOLICY_POLICY.fields_by_name['config']._serialized_options = b'\030\001'
  _globals['_CLUSTER']._serialized_start=674
  _globals['_CLUSTER']._serialized_end=6607
  _globals['_CLUSTER_TRANSPORTSOCKETMATCH']._serialized_start=3537
  _globals['_CLUSTER_TRANSPORTSOCKETMATCH']._serialized_end=3684
  _globals['_CLUSTER_CUSTOMCLUSTERTYPE']._serialized_start=3686
  _globals['_CLUSTER_CUSTOMCLUSTERTYPE']._serialized_end=3772
  _globals['_CLUSTER_EDSCLUSTERCONFIG']._serialized_start=3774
  _globals['_CLUSTER_EDSCLUSTERCONFIG']._serialized_end=3867
  _globals['_CLUSTER_LBSUBSETCONFIG']._serialized_start=3870
  _globals['_CLUSTER_LBSUBSETCONFIG']._serialized_end=4609
  _globals['_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR']._serialized_start=4222
  _globals['_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR']._serialized_end=4528
  _globals['_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR_LBSUBSETSELECTORFALLBACKPOLICY']._serialized_start=4407
  _globals['_CLUSTER_LBSUBSETCONFIG_LBSUBSETSELECTOR_LBSUBSETSELECTORFALLBACKPOLICY']._serialized_end=4528
  _globals['_CLUSTER_LBSUBSETCONFIG_LBSUBSETFALLBACKPOLICY']._serialized_start=4530
  _globals['_CLUSTER_LBSUBSETCONFIG_LBSUBSETFALLBACKPOLICY']._serialized_end=4609
  _globals['_CLUSTER_LEASTREQUESTLBCONFIG']._serialized_start=4611
  _globals['_CLUSTER_LEASTREQUESTLBCONFIG']._serialized_end=4694
  _globals['_CLUSTER_RINGHASHLBCONFIG']._serialized_start=4697
  _globals['_CLUSTER_RINGHASHLBCONFIG']._serialized_end=4993
  _globals['_CLUSTER_RINGHASHLBCONFIG_HASHFUNCTION']._serialized_start=4941
  _globals['_CLUSTER_RINGHASHLBCONFIG_HASHFUNCTION']._serialized_end=4987
  _globals['_CLUSTER_ORIGINALDSTLBCONFIG']._serialized_start=4995
  _globals['_CLUSTER_ORIGINALDSTLBCONFIG']._serialized_end=5041
  _globals['_CLUSTER_COMMONLBCONFIG']._serialized_start=5044
  _globals['_CLUSTER_COMMONLBCONFIG']._serialized_end=5824
  _globals['_CLUSTER_COMMONLBCONFIG_ZONEAWARELBCONFIG']._serialized_start=5552
  _globals['_CLUSTER_COMMONLBCONFIG_ZONEAWARELBCONFIG']._serialized_end=5704
  _globals['_CLUSTER_COMMONLBCONFIG_LOCALITYWEIGHTEDLBCONFIG']._serialized_start=5706
  _globals['_CLUSTER_COMMONLBCONFIG_LOCALITYWEIGHTEDLBCONFIG']._serialized_end=5732
  _globals['_CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG']._serialized_start=5734
  _globals['_CLUSTER_COMMONLBCONFIG_CONSISTENTHASHINGLBCONFIG']._serialized_end=5795
  _globals['_CLUSTER_REFRESHRATE']._serialized_start=5827
  _globals['_CLUSTER_REFRESHRATE']._serialized_end=5969
  _globals['_CLUSTER_EXTENSIONPROTOCOLOPTIONSENTRY']._serialized_start=5971
  _globals['_CLUSTER_EXTENSIONPROTOCOLOPTIONSENTRY']._serialized_end=6059
  _globals['_CLUSTER_TYPEDEXTENSIONPROTOCOLOPTIONSENTRY']._serialized_start=6061
  _globals['_CLUSTER_TYPEDEXTENSIONPROTOCOLOPTIONSENTRY']._serialized_end=6151
  _globals['_CLUSTER_DISCOVERYTYPE']._serialized_start=6153
  _globals['_CLUSTER_DISCOVERYTYPE']._serialized_end=6240
  _globals['_CLUSTER_LBPOLICY']._serialized_start=6243
  _globals['_CLUSTER_LBPOLICY']._serialized_end=6415
  _globals['_CLUSTER_DNSLOOKUPFAMILY']._serialized_start=6417
  _globals['_CLUSTER_DNSLOOKUPFAMILY']._serialized_end=6470
  _globals['_CLUSTER_CLUSTERPROTOCOLSELECTION']._serialized_start=6472
  _globals['_CLUSTER_CLUSTERPROTOCOLSELECTION']._serialized_end=6556
  _globals['_LOADBALANCINGPOLICY']._serialized_start=6610
  _globals['_LOADBALANCINGPOLICY']._serialized_end=6804
  _globals['_LOADBALANCINGPOLICY_POLICY']._serialized_start=6693
  _globals['_LOADBALANCINGPOLICY_POLICY']._serialized_end=6804
  _globals['_UPSTREAMBINDCONFIG']._serialized_start=6806
  _globals['_UPSTREAMBINDCONFIG']._serialized_end=6878
  _globals['_UPSTREAMCONNECTIONOPTIONS']._serialized_start=6880
  _globals['_UPSTREAMCONNECTIONOPTIONS']._serialized_end=6963
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/discovery/v2/rtds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%envoy/service/discovery/v2/rtds.proto\x12\x1a\x65nvoy.service.discovery.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x0b\n\tRtdsDummy\"H\n\x07Runtime\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12&\n\x05layer\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct2\xf1\x02\n\x17RuntimeDiscoveryService\x12V\n\rStreamRuntime\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12_\n\x0c\x44\x65ltaRuntime\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12q\n\x0c\x46\x65tchRuntime\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v2/discovery:runtime:\x01*\x1a*\x8a\xa4\x96\xf3\x07$\n\"envoy.service.discovery.v2.RuntimeB\xae\x01\n(io.envoyproxy.envoy.service.discovery.v2B\tRtdsProtoP\x01ZMgithub.com/envoyproxy/go-control-plane/envoy/service/discovery/v2;discoveryv2\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.service.runtime.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.discovery.v2.rtds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.envoyproxy.envoy.service.discovery.v2B\tRtdsProtoP\001ZMgithub.com/envoyproxy/go-control-plane/envoy/service/discovery/v2;discoveryv2\362\230\376\217\005\032\022\030envoy.service.runtime.v3\272\200\310\321\006\002\020\001'
  _RUNTIME.fields_by_name['name']._options = None
  _RUNTIME.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _RUNTIMEDISCOVERYSERVICE._options = None
  _RUNTIMEDISCOVERYSERVICE._serialized_options = b'\212\244\226\363\007$\n\"envoy.service.discovery.v2.Runtime'
  _RUNTIMEDISCOVERYSERVICE.methods_by_name['FetchRuntime']._options = None
  _RUNTIMEDISCOVERYSERVICE.methods_by_name['FetchRuntime']._serialized_options = b'\202\323\344\223\002\032\"\025/v2/discovery:runtime:\001*'
  _globals['_RTDSDUMMY']._serialized_start=281
  _globals['_RTDSDUMMY']._serialized_end=292
  _globals['_RUNTIME']._serialized_start=294
  _globals['_RUNTIME']._serialized_end=366
  _globals['_RUNTIMEDISCOVERYSERVICE']._serialized_start=369
  _globals['_RUNTIMEDISCOVERYSERVICE']._serialized_end=738
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/address.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import socket_option_pb2 as envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65nvoy/api/v2/core/address.proto\x12\x11\x65nvoy.api.v2.core\x1a%envoy/api/v2/core/socket_option.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"5\n\x04Pipe\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x16\n\x04mode\x18\x02 \x01(\rB\x08\xfa\x42\x05*\x03\x18\xff\x03\"\x88\x02\n\rSocketAddress\x12\x45\n\x08protocol\x18\x01 \x01(\x0e\x32).envoy.api.v2.core.SocketAddress.ProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1f\n\nport_value\x18\x03 \x01(\rB\t\xfa\x42\x06*\x04\x18\xff\xff\x03H\x00\x12\x14\n\nnamed_port\x18\x04 \x01(\tH\x00\x12\x15\n\rresolver_name\x18\x05 \x01(\t\x12\x13\n\x0bipv4_compat\x18\x06 \x01(\x08\"\x1c\n\x08Protocol\x12\x07\n\x03TCP\x10\x00\x12\x07\n\x03UDP\x10\x01\x42\x15\n\x0eport_specifier\x12\x03\xf8\x42\x01\"\xb6\x01\n\x0cTcpKeepalive\x12\x36\n\x10keepalive_probes\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x34\n\x0ekeepalive_time\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x38\n\x12keepalive_interval\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"\xb7\x01\n\nBindConfig\x12\x42\n\x0esource_address\x18\x01 \x01(\x0b\x32 .envoy.api.v2.core.SocketAddressB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12,\n\x08\x66reebind\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x0esocket_options\x18\x03 \x03(\x0b\x32\x1f.envoy.api.v2.core.SocketOption\"~\n\x07\x41\x64\x64ress\x12:\n\x0esocket_address\x18\x01 \x01(\x0b\x32 .envoy.api.v2.core.SocketAddressH\x00\x12\'\n\x04pipe\x18\x02 \x01(\x0b\x32\x17.envoy.api.v2.core.PipeH\x00\x42\x0e\n\x07\x61\x64\x64ress\x12\x03\xf8\x42\x01\"h\n\tCidrRange\x12\x1f\n\x0e\x61\x64\x64ress_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12:\n\nprefix_len\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05*\x03\x18\x80\x01\x42\x8f\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\x0c\x41\x64\x64ressProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.address_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\014AddressProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _PIPE.fields_by_name['path']._options = None
  _PIPE.fields_by_name['path']._serialized_options = b'\372B\004r\002 \001'
  _PIPE.fields_by_name['mode']._options = None
  _PIPE.fields_by_name['mode']._serialized_options = b'\372B\005*\003\030\377\003'
  _SOCKETADDRESS.oneofs_by_name['port_specifier']._options = None
  _SOCKETADDRESS.oneofs_by_name['port_specifier']._serialized_options = b'\370B\001'
  _SOCKETADDRESS.fields_by_name['protocol']._options = None
  _SOCKETADDRESS.fields_by_name['protocol']._serialized_options = b'\372B\005\202\001\002\020\001'
  _SOCKETADDRESS.fields_by_name['address']._options = None
  _SOCKETADDRESS.fields_by_name['address']._serialized_options = b'\372B\004r\002 \001'
  _SOCKETADDRESS.fields_by_name['port_value']._options = None
  _SOCKETADDRESS.fields_by_name['port_value']._serialized_options = b'\372B\006*\004\030\377\377\003'
  _BINDCONFIG.fields_by_name['source_address']._options = None
  _BINDCONFIG.fields_by_name['source_address']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ADDRESS.oneofs_by_name['address']._options = None
  _ADDRESS.oneofs_by_name['address']._serialized_options = b'\370B\001'
  _CIDRRANGE.fields_by_name['address_prefix']._options = None
  _CIDRRANGE.fields_by_name['address_prefix']._serialized_options = b'\372B\004r\002 \001'
  _CIDRRANGE.fields_by_name['prefix_len']._options = None
  _CIDRRANGE.fields_by_name['prefix_len']._serialized_options = b'\372B\005*\003\030\200\001'
  _globals['_PIPE']._serialized_start=213
  _globals['_PIPE']._serialized_end=266
  _globals['_SOCKETADDRESS']._serialized_start=269
  _globals['_SOCKETADDRESS']._serialized_end=533
  _globals['_SOCKETADDRESS_PROTOCOL']._serialized_start=482
  _globals['_SOCKETADDRESS_PROTOCOL']._serialized_end=510
  _globals['_TCPKEEPALIVE']._serialized_start=536
  _globals['_TCPKEEPALIVE']._serialized_end=718
  _globals['_BINDCONFIG']._serialized_start=721
  _globals['_BINDCONFIG']._serialized_end=904
  _globals['_ADDRESS']._serialized_start=906
  _globals['_ADDRESS']._serialized_end=1032
  _globals['_CIDRRANGE']._serialized_start=1034
  _globals['_CIDRRANGE']._serialized_end=1138
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/core/v3/cidr.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16xds/core/v3/cidr.proto\x12\x0bxds.core.v3\x1a\x1fxds/annotations/v3/status.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17validate/validate.proto\"h\n\tCidrRange\x12\x1f\n\x0e\x61\x64\x64ress_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12:\n\nprefix_len\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05*\x03\x18\x80\x01\x42V\n\x16\x63om.github.xds.core.v3B\x0e\x43idrRangeProtoP\x01Z\"github.com/cncf/xds/go/xds/core/v3\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.core.v3.cidr_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.github.xds.core.v3B\016CidrRangeProtoP\001Z\"github.com/cncf/xds/go/xds/core/v3\322\306\244\341\006\002\010\001'
  _CIDRRANGE.fields_by_name['address_prefix']._options = None
  _CIDRRANGE.fields_by_name['address_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _CIDRRANGE.fields_by_name['prefix_len']._options = None
  _CIDRRANGE.fields_by_name['prefix_len']._serialized_options = b'\372B\005*\003\030\200\001'
  _globals['_CIDRRANGE']._serialized_start=129
  _globals['_CIDRRANGE']._serialized_end=233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/load_balancing_policies/maglev/v3/maglev.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.load_balancing_policies.common.v3 import common_pb2 as envoy_dot_extensions_dot_load__balancing__policies_dot_common_dot_v3_dot_common__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?envoy/extensions/load_balancing_policies/maglev/v3/maglev.proto\x12\x32\x65nvoy.extensions.load_balancing_policies.maglev.v3\x1a?envoy/extensions/load_balancing_policies/common/v3/common.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc0\x02\n\x06Maglev\x12<\n\ntable_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\n\xfa\x42\x07\x32\x05\x18\xcb\x96\xb1\x02\x12s\n\x1c\x63onsistent_hashing_lb_config\x18\x02 \x01(\x0b\x32M.envoy.extensions.load_balancing_policies.common.v3.ConsistentHashingLbConfig\x12\x82\x01\n\x1blocality_weighted_lb_config\x18\x03 \x01(\x0b\x32].envoy.extensions.load_balancing_policies.common.v3.LocalityLbConfig.LocalityWeightedLbConfigB\xbd\x01\n@io.envoyproxy.envoy.extensions.load_balancing_policies.maglev.v3B\x0bMaglevProtoP\x01Zbgithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/maglev/v3;maglevv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.load_balancing_policies.maglev.v3.maglev_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n@io.envoyproxy.envoy.extensions.load_balancing_policies.maglev.v3B\013MaglevProtoP\001Zbgithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/maglev/v3;maglevv3\272\200\310\321\006\002\020\002'
  _MAGLEV.fields_by_name['table_size']._options = None
  _MAGLEV.fields_by_name['table_size']._serialized_options = b'\372B\0072\005\030\313\226\261\002'
  _globals['_MAGLEV']._serialized_start=273
  _globals['_MAGLEV']._serialized_end=593
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/trace/v3/trace_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from opencensus.proto.trace.v1 import trace_pb2 as opencensus_dot_proto_dot_trace_dot_v1_dot_trace__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*envoy/service/trace/v3/trace_service.proto\x12\x16\x65nvoy.service.trace.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a%opencensus/proto/trace/v1/trace.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"J\n\x14StreamTracesResponse:2\x9a\xc5\x88\x1e-\n+envoy.service.trace.v2.StreamTracesResponse\"\xc4\x02\n\x13StreamTracesMessage\x12J\n\nidentifier\x18\x01 \x01(\x0b\x32\x36.envoy.service.trace.v3.StreamTracesMessage.Identifier\x12.\n\x05spans\x18\x02 \x03(\x0b\x32\x1f.opencensus.proto.trace.v1.Span\x1a~\n\nIdentifier\x12\x32\n\x04node\x18\x01 \x01(\x0b\x32\x1a.envoy.config.core.v3.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:<\x9a\xc5\x88\x1e\x37\n5envoy.service.trace.v2.StreamTracesMessage.Identifier:1\x9a\xc5\x88\x1e,\n*envoy.service.trace.v2.StreamTracesMessage2}\n\x0cTraceService\x12m\n\x0cStreamTraces\x12+.envoy.service.trace.v3.StreamTracesMessage\x1a,.envoy.service.trace.v3.StreamTracesResponse\"\x00(\x01\x42\x8a\x01\n$io.envoyproxy.envoy.service.trace.v3B\x11TraceServiceProtoP\x01ZEgithub.com/envoyproxy/go-control-plane/envoy/service/trace/v3;tracev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.trace.v3.trace_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.envoyproxy.envoy.service.trace.v3B\021TraceServiceProtoP\001ZEgithub.com/envoyproxy/go-control-plane/envoy/service/trace/v3;tracev3\272\200\310\321\006\002\020\002'
  _STREAMTRACESRESPONSE._options = None
  _STREAMTRACESRESPONSE._serialized_options = b'\232\305\210\036-\n+envoy.service.trace.v2.StreamTracesResponse'
  _STREAMTRACESMESSAGE_IDENTIFIER.fields_by_name['node']._options = None
  _STREAMTRACESMESSAGE_IDENTIFIER.fields_by_name['node']._serialized_options = b'\372B\005\212\001\002\020\001'
  _STREAMTRACESMESSAGE_IDENTIFIER._options = None
  _STREAMTRACESMESSAGE_IDENTIFIER._serialized_options = b'\232\305\210\0367\n5envoy.service.trace.v2.StreamTracesMessage.Identifier'
  _STREAMTRACESMESSAGE._options = None
  _STREAMTRACESMESSAGE._serialized_options = b'\232\305\210\036,\n*envoy.service.trace.v2.StreamTracesMessage'
  _globals['_STREAMTRACESRESPONSE']._serialized_start=233
  _globals['_STREAMTRACESRESPONSE']._serialized_end=307
  _globals['_STREAMTRACESMESSAGE']._serialized_start=310
  _globals['_STREAMTRACESMESSAGE']._serialized_end=634
  _globals['_STREAMTRACESMESSAGE_IDENTIFIER']._serialized_start=457
  _globals['_STREAMTRACESMESSAGE_IDENTIFIER']._serialized_end=583
  _globals['_TRACESERVICE']._serialized_start=636
  _globals['_TRACESERVICE']._serialized_end=761
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/thrift_proxy/v2alpha1/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=envoy/config/filter/network/thrift_proxy/v2alpha1/route.proto\x12\x31\x65nvoy.config.filter.network.thrift_proxy.v2alpha1\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a)envoy/api/v2/route/route_components.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"l\n\x12RouteConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12H\n\x06routes\x18\x02 \x03(\x0b\x32\x38.envoy.config.filter.network.thrift_proxy.v2alpha1.Route\"\xb8\x01\n\x05Route\x12V\n\x05match\x18\x01 \x01(\x0b\x32=.envoy.config.filter.network.thrift_proxy.v2alpha1.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12W\n\x05route\x18\x02 \x01(\x0b\x32>.envoy.config.filter.network.thrift_proxy.v2alpha1.RouteActionB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x97\x01\n\nRouteMatch\x12\x15\n\x0bmethod_name\x18\x01 \x01(\tH\x00\x12\x16\n\x0cservice_name\x18\x02 \x01(\tH\x00\x12\x0e\n\x06invert\x18\x03 \x01(\x08\x12\x32\n\x07headers\x18\x04 \x03(\x0b\x32!.envoy.api.v2.route.HeaderMatcherB\x16\n\x0fmatch_specifier\x12\x03\xf8\x42\x01\"\xcc\x02\n\x0bRouteAction\x12\x1a\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01H\x00\x12_\n\x11weighted_clusters\x18\x02 \x01(\x0b\x32\x42.envoy.config.filter.network.thrift_proxy.v2alpha1.WeightedClusterH\x00\x12!\n\x0e\x63luster_header\x18\x06 \x01(\tB\x07\xfa\x42\x04r\x02 \x01H\x00\x12\x33\n\x0emetadata_match\x18\x03 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12\x32\n\x0brate_limits\x18\x04 \x03(\x0b\x32\x1d.envoy.api.v2.route.RateLimit\x12\x1a\n\x12strip_service_name\x18\x05 \x01(\x08\x42\x18\n\x11\x63luster_specifier\x12\x03\xf8\x42\x01\"\x94\x02\n\x0fWeightedCluster\x12l\n\x08\x63lusters\x18\x01 \x03(\x0b\x32P.envoy.config.filter.network.thrift_proxy.v2alpha1.WeightedCluster.ClusterWeightB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x92\x01\n\rClusterWeight\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x35\n\x06weight\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x33\n\x0emetadata_match\x18\x03 \x01(\x0b\x32\x1b.envoy.api.v2.core.MetadataB\xe9\x01\n?io.envoyproxy.envoy.config.filter.network.thrift_proxy.v2alpha1B\nRouteProtoP\x01ZXgithub.com/envoyproxy/go-control-plane/envoy/config/filter/network/thrift_proxy/v2alpha1\xf2\x98\xfe\x8f\x05\x32\x12\x30\x65nvoy.extensions.filters.network.thrift_proxy.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.network.thrift_proxy.v2alpha1.route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?io.envoyproxy.envoy.config.filter.network.thrift_proxy.v2alpha1B\nRouteProtoP\001ZXgithub.com/envoyproxy/go-control-plane/envoy/config/filter/network/thrift_proxy/v2alpha1\362\230\376\217\0052\0220envoy.extensions.filters.network.thrift_proxy.v3\272\200\310\321\006\002\020\001'
  _ROUTE.fields_by_name['match']._options = None
  _ROUTE.fields_by_name['match']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROUTE.fields_by_name['route']._options = None
  _ROUTE.fields_by_name['route']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROUTEMATCH.oneofs_by_name['match_specifier']._options = None
  _ROUTEMATCH.oneofs_by_name['match_specifier']._serialized_options = b'\370B\001'
  _ROUTEACTION.oneofs_by_name['cluster_specifier']._options = None
  _ROUTEACTION.oneofs_by_name['cluster_specifier']._serialized_options = b'\370B\001'
  _ROUTEACTION.fields_by_name['cluster']._options = None
  _ROUTEACTION.fields_by_name['cluster']._serialized_options = b'\372B\004r\002 \001'
  _ROUTEACTION.fields_by_name['cluster_header']._options = None
  _ROUTEACTION.fields_by_name['cluster_header']._serialized_options = b'\372B\004r\002 \001'
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['name']._options = None
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['weight']._options = None
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['weight']._serialized_options = b'\372B\004*\002(\001'
  _WEIGHTEDCLUSTER.fields_by_name['clusters']._options = None
  _WEIGHTEDCLUSTER.fields_by_name['clusters']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_ROUTECONFIGURATION']._serialized_start=309
  _globals['_ROUTECONFIGURATION']._serialized_end=417
  _globals['_ROUTE']._serialized_start=420
  _globals['_ROUTE']._serialized_end=604
  _globals['_ROUTEMATCH']._serialized_start=607
  _globals['_ROUTEMATCH']._serialized_end=758
  _globals['_ROUTEACTION']._serialized_start=761
  _globals['_ROUTEACTION']._serialized_end=1093
  _globals['_WEIGHTEDCLUSTER']._serialized_start=1096
  _globals['_WEIGHTEDCLUSTER']._serialized_end=1372
  _globals['_WEIGHTEDCLUSTER_CLUSTERWEIGHT']._serialized_start=1226
  _globals['_WEIGHTEDCLUSTER_CLUSTERWEIGHT']._serialized_end=1372
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/explain.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1alpha1 import value_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&google/api/expr/v1alpha1/explain.proto\x12\x18google.api.expr.v1alpha1\x1a$google/api/expr/v1alpha1/value.proto\"\xab\x01\n\x07\x45xplain\x12/\n\x06values\x18\x01 \x03(\x0b\x32\x1f.google.api.expr.v1alpha1.Value\x12>\n\nexpr_steps\x18\x02 \x03(\x0b\x32*.google.api.expr.v1alpha1.Explain.ExprStep\x1a+\n\x08\x45xprStep\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x13\n\x0bvalue_index\x18\x02 \x01(\x05:\x02\x18\x01\x42o\n\x1c\x63om.google.api.expr.v1alpha1B\x0c\x45xplainProtoP\x01Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1alpha1.explain_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.google.api.expr.v1alpha1B\014ExplainProtoP\001Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\370\001\001'
  _EXPLAIN._options = None
  _EXPLAIN._serialized_options = b'\030\001'
  _globals['_EXPLAIN']._serialized_start=107
  _globals['_EXPLAIN']._serialized_end=278
  _globals['_EXPLAIN_EXPRSTEP']._serialized_start=231
  _globals['_EXPLAIN_EXPRSTEP']._serialized_end=274
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/type/matcher/v3/range.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.type.v3 import range_pb2 as xds_dot_type_dot_v3_dot_range__pb2
from xds.type.matcher.v3 import matcher_pb2 as xds_dot_type_dot_matcher_dot_v3_dot_matcher__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fxds/type/matcher/v3/range.proto\x12\x13xds.type.matcher.v3\x1a\x17xds/type/v3/range.proto\x1a!xds/type/matcher/v3/matcher.proto\x1a\x17validate/validate.proto\"\xdb\x01\n\x11Int64RangeMatcher\x12K\n\x0erange_matchers\x18\x01 \x03(\x0b\x32\x33.xds.type.matcher.v3.Int64RangeMatcher.RangeMatcher\x1ay\n\x0cRangeMatcher\x12\x31\n\x06ranges\x18\x01 \x03(\x0b\x32\x17.xds.type.v3.Int64RangeB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x36\n\x08on_match\x18\x02 \x01(\x0b\x32$.xds.type.matcher.v3.Matcher.OnMatch\"\xdb\x01\n\x11Int32RangeMatcher\x12K\n\x0erange_matchers\x18\x01 \x03(\x0b\x32\x33.xds.type.matcher.v3.Int32RangeMatcher.RangeMatcher\x1ay\n\x0cRangeMatcher\x12\x31\n\x06ranges\x18\x01 \x03(\x0b\x32\x17.xds.type.v3.Int32RangeB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x36\n\x08on_match\x18\x02 \x01(\x0b\x32$.xds.type.matcher.v3.Matcher.OnMatch\"\xde\x01\n\x12\x44oubleRangeMatcher\x12L\n\x0erange_matchers\x18\x01 \x03(\x0b\x32\x34.xds.type.matcher.v3.DoubleRangeMatcher.RangeMatcher\x1az\n\x0cRangeMatcher\x12\x32\n\x06ranges\x18\x01 \x03(\x0b\x32\x18.xds.type.v3.DoubleRangeB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x36\n\x08on_match\x18\x02 \x01(\x0b\x32$.xds.type.matcher.v3.Matcher.OnMatchBZ\n\x1e\x63om.github.xds.type.matcher.v3B\nRangeProtoP\x01Z*github.com/cncf/xds/go/xds/type/matcher/v3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.type.matcher.v3.range_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.github.xds.type.matcher.v3B\nRangeProtoP\001Z*github.com/cncf/xds/go/xds/type/matcher/v3'
  _INT64RANGEMATCHER_RANGEMATCHER.fields_by_name['ranges']._options = None
  _INT64RANGEMATCHER_RANGEMATCHER.fields_by_name['ranges']._serialized_options = b'\372B\005\222\001\002\010\001'
  _INT32RANGEMATCHER_RANGEMATCHER.fields_by_name['ranges']._options = None
  _INT32RANGEMATCHER_RANGEMATCHER.fields_by_name['ranges']._serialized_options = b'\372B\005\222\001\002\010\001'
  _DOUBLERANGEMATCHER_RANGEMATCHER.fields_by_name['ranges']._options = None
  _DOUBLERANGEMATCHER_RANGEMATCHER.fields_by_name['ranges']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_INT64RANGEMATCHER']._serialized_start=142
  _globals['_INT64RANGEMATCHER']._serialized_end=361
  _globals['_INT64RANGEMATCHER_RANGEMATCHER']._serialized_start=240
  _globals['_INT64RANGEMATCHER_RANGEMATCHER']._serialized_end=361
  _globals['_INT32RANGEMATCHER']._serialized_start=364
  _globals['_INT32RANGEMATCHER']._serialized_end=583
  _globals['_INT32RANGEMATCHER_RANGEMATCHER']._serialized_start=462
  _globals['_INT32RANGEMATCHER_RANGEMATCHER']._serialized_end=583
  _globals['_DOUBLERANGEMATCHER']._serialized_start=586
  _globals['_DOUBLERANGEMATCHER']._serialized_end=808
  _globals['_DOUBLERANGEMATCHER_RANGEMATCHER']._serialized_start=686
  _globals['_DOUBLERANGEMATCHER_RANGEMATCHER']._serialized_end=808
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/expr.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16google/type/expr.proto\x12\x0bgoogle.type\"P\n\x04\x45xpr\x12\x12\n\nexpression\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\tBZ\n\x0f\x63om.google.typeB\tExprProtoP\x01Z4google.golang.org/genproto/googleapis/type/expr;expr\xa2\x02\x03GTPb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.expr_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017com.google.typeB\tExprProtoP\001Z4google.golang.org/genproto/googleapis/type/expr;expr\242\002\003GTP'
  _globals['_EXPR']._serialized_start=39
  _globals['_EXPR']._serialized_end=119
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/health_checkers/thrift/v3/thrift.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.filters.network.thrift_proxy.v3 import thrift_proxy_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_thrift__proxy_dot_v3_dot_thrift__proxy__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7envoy/extensions/health_checkers/thrift/v3/thrift.proto\x12*envoy.extensions.health_checkers.thrift.v3\x1a\x43\x65nvoy/extensions/filters/network/thrift_proxy/v3/thrift_proxy.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe0\x01\n\x06Thrift\x12\x1c\n\x0bmethod_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\\\n\ttransport\x18\x02 \x01(\x0e\x32?.envoy.extensions.filters.network.thrift_proxy.v3.TransportTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12Z\n\x08protocol\x18\x03 \x01(\x0e\x32>.envoy.extensions.filters.network.thrift_proxy.v3.ProtocolTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x42\xad\x01\n8io.envoyproxy.envoy.extensions.health_checkers.thrift.v3B\x0bThriftProtoP\x01ZZgithub.com/envoyproxy/go-control-plane/envoy/extensions/health_checkers/thrift/v3;thriftv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.health_checkers.thrift.v3.thrift_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8io.envoyproxy.envoy.extensions.health_checkers.thrift.v3B\013ThriftProtoP\001ZZgithub.com/envoyproxy/go-control-plane/envoy/extensions/health_checkers/thrift/v3;thriftv3\272\200\310\321\006\002\020\002'
  _THRIFT.fields_by_name['method_name']._options = None
  _THRIFT.fields_by_name['method_name']._serialized_options = b'\372B\004r\002\020\001'
  _THRIFT.fields_by_name['transport']._options = None
  _THRIFT.fields_by_name['transport']._serialized_options = b'\372B\005\202\001\002\020\001'
  _THRIFT.fields_by_name['protocol']._options = None
  _THRIFT.fields_by_name['protocol']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_THRIFT']._serialized_start=229
  _globals['_THRIFT']._serialized_end=453
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/endpoint/v3/leds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/service/endpoint/v3/leds.proto\x12\x19\x65nvoy.service.endpoint.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a envoy/annotations/resource.proto\x1a\x1dudpa/annotations/status.proto\"\x0b\n\tLedsDummy2\xd7\x01\n LocalityEndpointDiscoveryService\x12\x85\x01\n\x16\x44\x65ltaLocalityEndpoints\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x1a+\x8a\xa4\x96\xf3\x07%\n#envoy.config.endpoint.v3.LbEndpointB\x8b\x01\n\'io.envoyproxy.envoy.service.endpoint.v3B\tLedsProtoP\x01ZKgithub.com/envoyproxy/go-control-plane/envoy/service/endpoint/v3;endpointv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.endpoint.v3.leds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'io.envoyproxy.envoy.service.endpoint.v3B\tLedsProtoP\001ZKgithub.com/envoyproxy/go-control-plane/envoy/service/endpoint/v3;endpointv3\272\200\310\321\006\002\020\002'
  _LOCALITYENDPOINTDISCOVERYSERVICE._options = None
  _LOCALITYENDPOINTDISCOVERYSERVICE._serialized_options = b'\212\244\226\363\007%\n#envoy.config.endpoint.v3.LbEndpoint'
  _globals['_LEDSDUMMY']._serialized_start=176
  _globals['_LEDSDUMMY']._serialized_end=187
  _globals['_LOCALITYENDPOINTDISCOVERYSERVICE']._serialized_start=190
  _globals['_LOCALITYENDPOINTDISCOVERYSERVICE']._serialized_end=405
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/v3/path.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n envoy/type/matcher/v3/path.proto\x12\x15\x65nvoy.type.matcher.v3\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x81\x01\n\x0bPathMatcher\x12>\n\x04path\x18\x01 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.type.matcher.PathMatcherB\x0b\n\x04rule\x12\x03\xf8\x42\x01\x42\x82\x01\n#io.envoyproxy.envoy.type.matcher.v3B\tPathProtoP\x01ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.v3.path_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.type.matcher.v3B\tPathProtoP\001ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\272\200\310\321\006\002\020\002'
  _PATHMATCHER.oneofs_by_name['rule']._options = None
  _PATHMATCHER.oneofs_by_name['rule']._serialized_options = b'\370B\001'
  _PATHMATCHER.fields_by_name['path']._options = None
  _PATHMATCHER.fields_by_name['path']._serialized_options = b'\372B\005\212\001\002\020\001'
  _PATHMATCHER._options = None
  _PATHMATCHER._serialized_options = b'\232\305\210\036 \n\036envoy.type.matcher.PathMatcher'
  _globals['_PATHMATCHER']._serialized_start=187
  _globals['_PATHMATCHER']._serialized_end=316
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/servicecontrol/v1/operation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.servicecontrol.v1 import log_entry_pb2 as google_dot_api_dot_servicecontrol_dot_v1_dot_log__entry__pb2
from google.api.servicecontrol.v1 import metric_value_pb2 as google_dot_api_dot_servicecontrol_dot_v1_dot_metric__value__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,google/api/servicecontrol/v1/operation.proto\x12\x1cgoogle.api.servicecontrol.v1\x1a,google/api/servicecontrol/v1/log_entry.proto\x1a/google/api/servicecontrol/v1/metric_value.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb9\x04\n\tOperation\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12\x16\n\x0eoperation_name\x18\x02 \x01(\t\x12\x13\n\x0b\x63onsumer_id\x18\x03 \x01(\t\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x06labels\x18\x06 \x03(\x0b\x32\x33.google.api.servicecontrol.v1.Operation.LabelsEntry\x12G\n\x11metric_value_sets\x18\x07 \x03(\x0b\x32,.google.api.servicecontrol.v1.MetricValueSet\x12;\n\x0blog_entries\x18\x08 \x03(\x0b\x32&.google.api.servicecontrol.v1.LogEntry\x12\x46\n\nimportance\x18\x0b \x01(\x0e\x32\x32.google.api.servicecontrol.v1.Operation.Importance\x12(\n\nextensions\x18\x10 \x03(\x0b\x32\x14.google.protobuf.Any\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1f\n\nImportance\x12\x07\n\x03LOW\x10\x00\x12\x08\n\x04HIGH\x10\x01\x42\xe9\x01\n com.google.api.servicecontrol.v1B\x0eOperationProtoP\x01ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\xf8\x01\x01\xaa\x02\x1eGoogle.Cloud.ServiceControl.V1\xca\x02\x1eGoogle\\Cloud\\ServiceControl\\V1\xea\x02!Google::Cloud::ServiceControl::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.servicecontrol.v1.operation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n com.google.api.servicecontrol.v1B\016OperationProtoP\001ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\370\001\001\252\002\036Google.Cloud.ServiceControl.V1\312\002\036Google\\Cloud\\ServiceControl\\V1\352\002!Google::Cloud::ServiceControl::V1'
  _OPERATION_LABELSENTRY._options = None
  _OPERATION_LABELSENTRY._serialized_options = b'8\001'
  _globals['_OPERATION']._serialized_start=234
  _globals['_OPERATION']._serialized_end=803
  _globals['_OPERATION_LABELSENTRY']._serialized_start=725
  _globals['_OPERATION_LABELSENTRY']._serialized_end=770
  _globals['_OPERATION_IMPORTANCE']._serialized_start=772
  _globals['_OPERATION_IMPORTANCE']._serialized_end=803
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/matching/input_matchers/runtime_fraction/v3/runtime_fraction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSenvoy/extensions/matching/input_matchers/runtime_fraction/v3/runtime_fraction.proto\x12<envoy.extensions.matching.input_matchers.runtime_fraction.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"s\n\x0fRuntimeFraction\x12R\n\x10runtime_fraction\x18\x01 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercentB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0c\n\x04seed\x18\x02 \x01(\x04\x42\xe4\x01\nJio.envoyproxy.envoy.extensions.matching.input_matchers.runtime_fraction.v3B\x14RuntimeFractionProtoP\x01Zvgithub.com/envoyproxy/go-control-plane/envoy/extensions/matching/input_matchers/runtime_fraction/v3;runtime_fractionv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.matching.input_matchers.runtime_fraction.v3.runtime_fraction_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nJio.envoyproxy.envoy.extensions.matching.input_matchers.runtime_fraction.v3B\024RuntimeFractionProtoP\001Zvgithub.com/envoyproxy/go-control-plane/envoy/extensions/matching/input_matchers/runtime_fraction/v3;runtime_fractionv3\272\200\310\321\006\002\020\002'
  _RUNTIMEFRACTION.fields_by_name['runtime_fraction']._options = None
  _RUNTIMEFRACTION.fields_by_name['runtime_fraction']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_RUNTIMEFRACTION']._serialized_start=238
  _globals['_RUNTIMEFRACTION']._serialized_end=353
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v3/opentelemetry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)envoy/config/trace/v3/opentelemetry.proto\x12\x15\x65nvoy.config.trace.v3\x1a\'envoy/config/core/v3/grpc_service.proto\x1a\x1dudpa/annotations/status.proto\"d\n\x13OpenTelemetryConfig\x12\x37\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32!.envoy.config.core.v3.GrpcService\x12\x14\n\x0cservice_name\x18\x02 \x01(\tB\x89\x01\n#io.envoyproxy.envoy.config.trace.v3B\x12OpentelemetryProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v3.opentelemetry_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v3B\022OpentelemetryProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\272\200\310\321\006\002\020\002'
  _globals['_OPENTELEMETRYCONFIG']._serialized_start=140
  _globals['_OPENTELEMETRYCONFIG']._serialized_end=240
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/usage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16google/api/usage.proto\x12\ngoogle.api\"j\n\x05Usage\x12\x14\n\x0crequirements\x18\x01 \x03(\t\x12$\n\x05rules\x18\x06 \x03(\x0b\x32\x15.google.api.UsageRule\x12%\n\x1dproducer_notification_channel\x18\x07 \x01(\t\"]\n\tUsageRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12 \n\x18\x61llow_unregistered_calls\x18\x02 \x01(\x08\x12\x1c\n\x14skip_service_control\x18\x03 \x01(\x08\x42l\n\x0e\x63om.google.apiB\nUsageProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.usage_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\nUsageProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\242\002\004GAPI'
  _globals['_USAGE']._serialized_start=38
  _globals['_USAGE']._serialized_end=144
  _globals['_USAGERULE']._serialized_start=146
  _globals['_USAGERULE']._serialized_end=239
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/core/v3/collection_entry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from xds.core.v3 import resource_locator_pb2 as xds_dot_core_dot_v3_dot_resource__locator__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"xds/core/v3/collection_entry.proto\x12\x0bxds.core.v3\x1a\x19google/protobuf/any.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\"xds/core/v3/resource_locator.proto\x1a\x17validate/validate.proto\"\x93\x02\n\x0f\x43ollectionEntry\x12/\n\x07locator\x18\x01 \x01(\x0b\x32\x1c.xds.core.v3.ResourceLocatorH\x00\x12@\n\x0cinline_entry\x18\x02 \x01(\x0b\x32(.xds.core.v3.CollectionEntry.InlineEntryH\x00\x1ar\n\x0bInlineEntry\x12*\n\x04name\x18\x01 \x01(\tB\x1c\xfa\x42\x19r\x17\x32\x15^[0-9a-zA-Z_\\-\\.~:]+$\x12\x0f\n\x07version\x18\x02 \x01(\t\x12&\n\x08resource\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x19\n\x12resource_specifier\x12\x03\xf8\x42\x01\x42\\\n\x16\x63om.github.xds.core.v3B\x14\x43ollectionEntryProtoP\x01Z\"github.com/cncf/xds/go/xds/core/v3\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.core.v3.collection_entry_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.github.xds.core.v3B\024CollectionEntryProtoP\001Z\"github.com/cncf/xds/go/xds/core/v3\322\306\244\341\006\002\010\001'
  _COLLECTIONENTRY_INLINEENTRY.fields_by_name['name']._options = None
  _COLLECTIONENTRY_INLINEENTRY.fields_by_name['name']._serialized_options = b'\372B\031r\0272\025^[0-9a-zA-Z_\\-\\.~:]+$'
  _COLLECTIONENTRY.oneofs_by_name['resource_specifier']._options = None
  _COLLECTIONENTRY.oneofs_by_name['resource_specifier']._serialized_options = b'\370B\001'
  _globals['_COLLECTIONENTRY']._serialized_start=173
  _globals['_COLLECTIONENTRY']._serialized_end=448
  _globals['_COLLECTIONENTRY_INLINEENTRY']._serialized_start=307
  _globals['_COLLECTIONENTRY_INLINEENTRY']._serialized_end=421
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/v3/status_code_input.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-envoy/type/matcher/v3/status_code_input.proto\x12\x15\x65nvoy.type.matcher.v3\x1a\x1dudpa/annotations/status.proto\"\"\n HttpResponseStatusCodeMatchInput\"\'\n%HttpResponseStatusCodeClassMatchInputB\x8d\x01\n#io.envoyproxy.envoy.type.matcher.v3B\x14StatusCodeInputProtoP\x01ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.v3.status_code_input_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.type.matcher.v3B\024StatusCodeInputProtoP\001ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\272\200\310\321\006\002\020\002'
  _globals['_HTTPRESPONSESTATUSCODEMATCHINPUT']._serialized_start=103
  _globals['_HTTPRESPONSESTATUSCODEMATCHINPUT']._serialized_end=137
  _globals['_HTTPRESPONSESTATUSCODECLASSMATCHINPUT']._serialized_start=139
  _globals['_HTTPRESPONSESTATUSCODECLASSMATCHINPUT']._serialized_end=178
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/discovery/v2/ads.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/service/discovery/v2/ads.proto\x12\x1a\x65nvoy.service.discovery.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1dudpa/annotations/status.proto\"\n\n\x08\x41\x64sDummy2\xed\x01\n\x1a\x41ggregatedDiscoveryService\x12\x62\n\x19StreamAggregatedResources\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12k\n\x18\x44\x65ltaAggregatedResources\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x42\x8d\x01\n(io.envoyproxy.envoy.service.discovery.v2B\x08\x41\x64sProtoP\x01ZMgithub.com/envoyproxy/go-control-plane/envoy/service/discovery/v2;discoveryv2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.discovery.v2.ads_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.envoyproxy.envoy.service.discovery.v2B\010AdsProtoP\001ZMgithub.com/envoyproxy/go-control-plane/envoy/service/discovery/v2;discoveryv2\272\200\310\321\006\002\020\001'
  _globals['_ADSDUMMY']._serialized_start=129
  _globals['_ADSDUMMY']._serialized_end=139
  _globals['_AGGREGATEDDISCOVERYSERVICE']._serialized_start=142
  _globals['_AGGREGATEDDISCOVERYSERVICE']._serialized_end=379
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/retry/priority/previous_priorities/v3/previous_priorities_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWenvoy/extensions/retry/priority/previous_priorities/v3/previous_priorities_config.proto\x12\x36\x65nvoy.extensions.retry.priority.previous_priorities.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x85\x01\n\x18PreviousPrioritiesConfig\x12!\n\x10update_frequency\x18\x01 \x01(\x05\x42\x07\xfa\x42\x04\x1a\x02 \x00:F\x9a\xc5\x88\x1e\x41\n?envoy.config.retry.previous_priorities.PreviousPrioritiesConfigB\xe4\x01\nDio.envoyproxy.envoy.extensions.retry.priority.previous_priorities.v3B\x1dPreviousPrioritiesConfigProtoP\x01Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/retry/priority/previous_priorities/v3;previous_prioritiesv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.retry.priority.previous_priorities.v3.previous_priorities_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nDio.envoyproxy.envoy.extensions.retry.priority.previous_priorities.v3B\035PreviousPrioritiesConfigProtoP\001Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/retry/priority/previous_priorities/v3;previous_prioritiesv3\272\200\310\321\006\002\020\002'
  _PREVIOUSPRIORITIESCONFIG.fields_by_name['update_frequency']._options = None
  _PREVIOUSPRIORITIESCONFIG.fields_by_name['update_frequency']._serialized_options = b'\372B\004\032\002 \000'
  _PREVIOUSPRIORITIESCONFIG._options = None
  _PREVIOUSPRIORITIESCONFIG._serialized_options = b'\232\305\210\036A\n?envoy.config.retry.previous_priorities.PreviousPrioritiesConfig'
  _globals['_PREVIOUSPRIORITIESCONFIG']._serialized_start=239
  _globals['_PREVIOUSPRIORITIESCONFIG']._serialized_end=372
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/thrift_proxy/v3/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<envoy/extensions/filters/network/thrift_proxy/v3/route.proto\x12\x30\x65nvoy.extensions.filters.network.thrift_proxy.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a,envoy/config/route/v3/route_components.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xef\x01\n\x12RouteConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12G\n\x06routes\x18\x02 \x03(\x0b\x32\x37.envoy.extensions.filters.network.thrift_proxy.v3.Route\x12\x35\n\x11validate_clusters\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:K\x9a\xc5\x88\x1e\x46\nDenvoy.config.filter.network.thrift_proxy.v2alpha1.RouteConfiguration\"\xf6\x01\n\x05Route\x12U\n\x05match\x18\x01 \x01(\x0b\x32<.envoy.extensions.filters.network.thrift_proxy.v3.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12V\n\x05route\x18\x02 \x01(\x0b\x32=.envoy.extensions.filters.network.thrift_proxy.v3.RouteActionB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:>\x9a\xc5\x88\x1e\x39\n7envoy.config.filter.network.thrift_proxy.v2alpha1.Route\"\xdf\x01\n\nRouteMatch\x12\x15\n\x0bmethod_name\x18\x01 \x01(\tH\x00\x12\x16\n\x0cservice_name\x18\x02 \x01(\tH\x00\x12\x0e\n\x06invert\x18\x03 \x01(\x08\x12\x35\n\x07headers\x18\x04 \x03(\x0b\x32$.envoy.config.route.v3.HeaderMatcher:C\x9a\xc5\x88\x1e>\n<envoy.config.filter.network.thrift_proxy.v2alpha1.RouteMatchB\x16\n\x0fmatch_specifier\x12\x03\xf8\x42\x01\"\x8c\x05\n\x0bRouteAction\x12\x1a\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12^\n\x11weighted_clusters\x18\x02 \x01(\x0b\x32\x41.envoy.extensions.filters.network.thrift_proxy.v3.WeightedClusterH\x00\x12\'\n\x0e\x63luster_header\x18\x06 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x02\xc8\x01\x00H\x00\x12\x36\n\x0emetadata_match\x18\x03 \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata\x12\x35\n\x0brate_limits\x18\x04 \x03(\x0b\x32 .envoy.config.route.v3.RateLimit\x12\x1a\n\x12strip_service_name\x18\x05 \x01(\x08\x12r\n\x17request_mirror_policies\x18\x07 \x03(\x0b\x32Q.envoy.extensions.filters.network.thrift_proxy.v3.RouteAction.RequestMirrorPolicy\x1ay\n\x13RequestMirrorPolicy\x12\x18\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12H\n\x10runtime_fraction\x18\x02 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent:D\x9a\xc5\x88\x1e?\n=envoy.config.filter.network.thrift_proxy.v2alpha1.RouteActionB\x18\n\x11\x63luster_specifier\x12\x03\xf8\x42\x01\"\xb8\x03\n\x0fWeightedCluster\x12k\n\x08\x63lusters\x18\x01 \x03(\x0b\x32O.envoy.extensions.filters.network.thrift_proxy.v3.WeightedCluster.ClusterWeightB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xed\x01\n\rClusterWeight\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x35\n\x06weight\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x36\n\x0emetadata_match\x18\x03 \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata:V\x9a\xc5\x88\x1eQ\nOenvoy.config.filter.network.thrift_proxy.v2alpha1.WeightedCluster.ClusterWeight:H\x9a\xc5\x88\x1e\x43\nAenvoy.config.filter.network.thrift_proxy.v2alpha1.WeightedClusterB\xbe\x01\n>io.envoyproxy.envoy.extensions.filters.network.thrift_proxy.v3B\nRouteProtoP\x01Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/thrift_proxy/v3;thrift_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.thrift_proxy.v3.route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>io.envoyproxy.envoy.extensions.filters.network.thrift_proxy.v3B\nRouteProtoP\001Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/thrift_proxy/v3;thrift_proxyv3\272\200\310\321\006\002\020\002'
  _ROUTECONFIGURATION._options = None
  _ROUTECONFIGURATION._serialized_options = b'\232\305\210\036F\nDenvoy.config.filter.network.thrift_proxy.v2alpha1.RouteConfiguration'
  _ROUTE.fields_by_name['match']._options = None
  _ROUTE.fields_by_name['match']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROUTE.fields_by_name['route']._options = None
  _ROUTE.fields_by_name['route']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROUTE._options = None
  _ROUTE._serialized_options = b'\232\305\210\0369\n7envoy.config.filter.network.thrift_proxy.v2alpha1.Route'
  _ROUTEMATCH.oneofs_by_name['match_specifier']._options = None
  _ROUTEMATCH.oneofs_by_name['match_specifier']._serialized_options = b'\370B\001'
  _ROUTEMATCH._options = None
  _ROUTEMATCH._serialized_options = b'\232\305\210\036>\n<envoy.config.filter.network.thrift_proxy.v2alpha1.RouteMatch'
  _ROUTEACTION_REQUESTMIRRORPOLICY.fields_by_name['cluster']._options = None
  _ROUTEACTION_REQUESTMIRRORPOLICY.fields_by_name['cluster']._serialized_options = b'\372B\004r\002\020\001'
  _ROUTEACTION.oneofs_by_name['cluster_specifier']._options = None
  _ROUTEACTION.oneofs_by_name['cluster_specifier']._serialized_options = b'\370B\001'
  _ROUTEACTION.fields_by_name['cluster']._options = None
  _ROUTEACTION.fields_by_name['cluster']._serialized_options = b'\372B\004r\002\020\001'
  _ROUTEACTION.fields_by_name['cluster_header']._options = None
  _ROUTEACTION.fields_by_name['cluster_header']._serialized_options = b'\372B\nr\010\020\001\300\001\002\310\001\000'
  _ROUTEACTION._options = None
  _ROUTEACTION._serialized_options = b'\232\305\210\036?\n=envoy.config.filter.network.thrift_proxy.v2alpha1.RouteAction'
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['name']._options = None
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['weight']._options = None
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['weight']._serialized_options = b'\372B\004*\002(\001'
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT._options = None
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT._serialized_options = b'\232\305\210\036Q\nOenvoy.config.filter.network.thrift_proxy.v2alpha1.WeightedCluster.ClusterWeight'
  _WEIGHTEDCLUSTER.fields_by_name['clusters']._options = None
  _WEIGHTEDCLUSTER.fields_by_name['clusters']._serialized_options = b'\372B\005\222\001\002\010\001'
  _WEIGHTEDCLUSTER._options = None
  _WEIGHTEDCLUSTER._serialized_options = b'\232\305\210\036C\nAenvoy.config.filter.network.thrift_proxy.v2alpha1.WeightedCluster'
  _globals['_ROUTECONFIGURATION']._serialized_start=317
  _globals['_ROUTECONFIGURATION']._serialized_end=556
  _globals['_ROUTE']._serialized_start=559
  _globals['_ROUTE']._serialized_end=805
  _globals['_ROUTEMATCH']._serialized_start=808
  _globals['_ROUTEMATCH']._serialized_end=1031
  _globals['_ROUTEACTION']._serialized_start=1034
  _globals['_ROUTEACTION']._serialized_end=1686
  _globals['_ROUTEACTION_REQUESTMIRRORPOLICY']._serialized_start=1469
  _globals['_ROUTEACTION_REQUESTMIRRORPOLICY']._serialized_end=1590
  _globals['_WEIGHTEDCLUSTER']._serialized_start=1689
  _globals['_WEIGHTEDCLUSTER']._serialized_end=2129
  _globals['_WEIGHTEDCLUSTER_CLUSTERWEIGHT']._serialized_start=1818
  _globals['_WEIGHTEDCLUSTER_CLUSTERWEIGHT']._serialized_end=2055
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/zookeeper_proxy/v3/zookeeper_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIenvoy/extensions/filters/network/zookeeper_proxy/v3/zookeeper_proxy.proto\x12\x33\x65nvoy.extensions.filters.network.zookeeper_proxy.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb0\x03\n\x0eZooKeeperProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\naccess_log\x18\x02 \x01(\t\x12\x36\n\x10max_packet_bytes\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12(\n enable_latency_threshold_metrics\x18\x04 \x01(\x08\x12J\n\x19\x64\x65\x66\x61ult_latency_threshold\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06\x32\x04\x10\xc0\x84=\x12r\n\x1blatency_threshold_overrides\x18\x06 \x03(\x0b\x32M.envoy.extensions.filters.network.zookeeper_proxy.v3.LatencyThresholdOverride:J\x9a\xc5\x88\x1e\x45\nCenvoy.config.filter.network.zookeeper_proxy.v1alpha1.ZooKeeperProxy\"\xcd\x04\n\x18LatencyThresholdOverride\x12n\n\x06opcode\x18\x01 \x01(\x0e\x32T.envoy.extensions.filters.network.zookeeper_proxy.v3.LatencyThresholdOverride.OpcodeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12<\n\tthreshold\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xfa\x42\x0b\xaa\x01\x08\x08\x01\x32\x04\x10\xc0\x84=\"\x82\x03\n\x06Opcode\x12\x0b\n\x07\x43onnect\x10\x00\x12\n\n\x06\x43reate\x10\x01\x12\n\n\x06\x44\x65lete\x10\x02\x12\n\n\x06\x45xists\x10\x03\x12\x0b\n\x07GetData\x10\x04\x12\x0b\n\x07SetData\x10\x05\x12\n\n\x06GetAcl\x10\x06\x12\n\n\x06SetAcl\x10\x07\x12\x0f\n\x0bGetChildren\x10\x08\x12\x08\n\x04Sync\x10\t\x12\x08\n\x04Ping\x10\n\x12\x10\n\x0cGetChildren2\x10\x0b\x12\t\n\x05\x43heck\x10\x0c\x12\t\n\x05Multi\x10\r\x12\x0b\n\x07\x43reate2\x10\x0e\x12\x0c\n\x08Reconfig\x10\x0f\x12\x10\n\x0c\x43heckWatches\x10\x10\x12\x11\n\rRemoveWatches\x10\x11\x12\x13\n\x0f\x43reateContainer\x10\x12\x12\r\n\tCreateTtl\x10\x13\x12\t\n\x05\x43lose\x10\x14\x12\x0b\n\x07SetAuth\x10\x15\x12\x0e\n\nSetWatches\x10\x16\x12\x11\n\rGetEphemerals\x10\x17\x12\x18\n\x14GetAllChildrenNumber\x10\x18\x12\x0f\n\x0bSetWatches2\x10\x19\x42\xd0\x01\nAio.envoyproxy.envoy.extensions.filters.network.zookeeper_proxy.v3B\x13ZookeeperProxyProtoP\x01Zlgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/zookeeper_proxy/v3;zookeeper_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.zookeeper_proxy.v3.zookeeper_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nAio.envoyproxy.envoy.extensions.filters.network.zookeeper_proxy.v3B\023ZookeeperProxyProtoP\001Zlgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/zookeeper_proxy/v3;zookeeper_proxyv3\272\200\310\321\006\002\020\002'
  _ZOOKEEPERPROXY.fields_by_name['stat_prefix']._options = None
  _ZOOKEEPERPROXY.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _ZOOKEEPERPROXY.fields_by_name['default_latency_threshold']._options = None
  _ZOOKEEPERPROXY.fields_by_name['default_latency_threshold']._serialized_options = b'\372B\t\252\001\0062\004\020\300\204='
  _ZOOKEEPERPROXY._options = None
  _ZOOKEEPERPROXY._serialized_options = b'\232\305\210\036E\nCenvoy.config.filter.network.zookeeper_proxy.v1alpha1.ZooKeeperProxy'
  _LATENCYTHRESHOLDOVERRIDE.fields_by_name['opcode']._options = None
  _LATENCYTHRESHOLDOVERRIDE.fields_by_name['opcode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _LATENCYTHRESHOLDOVERRIDE.fields_by_name['threshold']._options = None
  _LATENCYTHRESHOLDOVERRIDE.fields_by_name['threshold']._serialized_options = b'\372B\013\252\001\010\010\0012\004\020\300\204='
  _globals['_ZOOKEEPERPROXY']._serialized_start=286
  _globals['_ZOOKEEPERPROXY']._serialized_end=718
  _globals['_LATENCYTHRESHOLDOVERRIDE']._serialized_start=721
  _globals['_LATENCYTHRESHOLDOVERRIDE']._serialized_end=1310
  _globals['_LATENCYTHRESHOLDOVERRIDE_OPCODE']._serialized_start=924
  _globals['_LATENCYTHRESHOLDOVERRIDE_OPCODE']._serialized_end=1310
# @@protoc_insertion_point(module_scope)
